diff -ru fltk-1.1.9/FL/Fl_Window.H fltk-1.1.9_ontop/FL/Fl_Window.H
--- fltk-1.1.9/FL/Fl_Window.H	2005-07-15 11:34:53.000000000 +0200
+++ fltk-1.1.9_ontop/FL/Fl_Window.H	2008-06-11 19:18:35.000000000 +0200
@@ -88,6 +88,7 @@
   int modal() const	{return flags() & FL_MODAL;}
   void set_non_modal()	{set_flag(FL_NON_MODAL);}
   int non_modal() const {return flags() & (FL_NON_MODAL|FL_MODAL);}
+  void stay_on_top(int ontop);
 
   void hotspot(int x, int y, int offscreen = 0);
   void hotspot(const Fl_Widget*, int offscreen = 0);
diff -ru fltk-1.1.9/src/Fl_mac.cxx fltk-1.1.9_ontop/src/Fl_mac.cxx
--- fltk-1.1.9/src/Fl_mac.cxx	2008-02-20 19:17:34.000000000 +0100
+++ fltk-1.1.9_ontop/src/Fl_mac.cxx	2008-06-12 17:09:03.000000000 +0200
@@ -2091,6 +2091,19 @@
   }
 }
 
+/**
+ * activate/deactivate stay on top
+ */
+void Fl_Window::stay_on_top(int ontop) {
+    WindowClass win_class;
+
+    GetWindowClass(i->xid, &win_class);
+
+    if(ontop && win_class == kDocumentWindowClass)
+        SetWindowClass(i->xid, kUtilityWindowClass);
+    if(!ontop && win_class == kUtilityWindowClass)
+        SetWindowClass(i->xid, kDocumentWindowClass);
+}
 
 /**
  * resize a window
diff -ru fltk-1.1.9/src/Fl_win32.cxx fltk-1.1.9_ontop/src/Fl_win32.cxx
--- fltk-1.1.9/src/Fl_win32.cxx	2008-01-10 22:53:34.000000000 +0100
+++ fltk-1.1.9_ontop/src/Fl_win32.cxx	2008-06-11 19:22:15.000000000 +0200
@@ -1551,6 +1551,12 @@
   }
 }
 
+// activate/deactivate stay on top
+void Fl_Window::stay_on_top(int ontop) {
+  SetWindowPos(i->xid, ontop ? HWND_TOPMOST : HWND_NOTOPMOST,
+          0,0,0,0, SWP_NOMOVE|SWP_NOSIZE|SWP_NOOWNERZORDER);
+}
+
 Fl_Window *Fl_Window::current_;
 // the current context
 HDC fl_gc = 0;
diff -ru fltk-1.1.9/src/Fl_x.cxx fltk-1.1.9_ontop/src/Fl_x.cxx
--- fltk-1.1.9/src/Fl_x.cxx	2007-06-18 15:08:57.000000000 +0200
+++ fltk-1.1.9_ontop/src/Fl_x.cxx	2008-06-11 19:19:38.000000000 +0200
@@ -1392,6 +1392,28 @@
   }
 }
 
+// activate/deactivate stay on top
+void Fl_Window::stay_on_top(int ontop) {
+    XEvent e;
+
+    Atom WM_STATE = XInternAtom(fl_display, "_NET_WM_STATE", 0);
+    Atom WM_STATE_ABOVE = XInternAtom(fl_display, "_NET_WM_STATE_ABOVE", 0);
+
+    e.xclient.type = ClientMessage;
+    e.xclient.window = i->xid;
+    e.xclient.message_type = WM_STATE;
+    e.xclient.format = 32;
+    e.xclient.data.l[0] = (long)ontop;
+    e.xclient.data.l[1] = (long)WM_STATE_ABOVE;
+    e.xclient.data.l[2] = (long)0;
+    e.xclient.data.l[3] = (long)0;
+    e.xclient.data.l[4] = (long)0;
+
+    XSendEvent(fl_display, RootWindow(fl_display, fl_screen), 0,
+            SubstructureNotifyMask|SubstructureRedirectMask, &e);
+    XFlush(fl_display);
+}
+
 Window fl_window;
 Fl_Window *Fl_Window::current_;
 GC fl_gc;
